Just wanted to let you know, I've changed the Note of the Day Plugin
to create notes with titles like this ("NotD" -> "Today"):

   Today: Friday, January 26 2007

...instead of...

   NotD: Friday, January 26 2007

The committed patch is attached.

Thanks,

Boyd
Index: Tomboy/Plugins/NoteOfTheDay.cs
===================================================================
--- Tomboy/Plugins/NoteOfTheDay.cs	(revision 917)
+++ Tomboy/Plugins/NoteOfTheDay.cs	(working copy)
@@ -10,12 +10,12 @@
 
 class NoteOfTheDay 
 {
-	static string title_prefix = Catalog.GetString ("NotD: ");
-	static string template_title = Catalog.GetString ("NotD: Template");
+	static string title_prefix = Catalog.GetString ("Today: ");
+	static string template_title = Catalog.GetString ("Today: Template");
 
 	public static string GetTitle (DateTime day)
 	{
 		// Format: "NotD: Friday, July 01 2005"
 		return title_prefix + day.ToString (Catalog.GetString ("dddd, MMMM d yyyy"));
 	}
 
@@ -94,7 +94,7 @@
 		}
 		
 		foreach (Note note in kill_list) {
-			Logger.Log ("NotD: Deleting old unmodified '{0}'",
+			Logger.Log ("NoteOfTheDay: Deleting old unmodified '{0}'",
 					   note.Title);
 			manager.Delete (note);
 		}
@@ -10,12 +10,12 @@
 	public static string GetTitle (DateTime day)
 	{
-		// Format: "NotD: Friday, July 01 2005"
+		// Format: "Today: Friday, July 01 2005"
 		return title_prefix + day.ToString (Catalog.GetString ("dddd, MMMM d yyyy"));
 	}
_______________________________________________
gnome-i18n mailing list
gnome-i18n@gnome.org
http://mail.gnome.org/mailman/listinfo/gnome-i18n

Reply via email to